'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.renderWithIntl = exports.mountWithIntl = exports.shallowWithIntl = undefined;

var _reactIntl = require('react-intl');

var _enzymeAdapterReact = require('enzyme-adapter-react-16');

var _enzymeAdapterReact2 = _interopRequireDefault(_enzymeAdapterReact);

var _enzyme = require('enzyme');

var _enzyme2 = _interopRequireDefault(_enzyme);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _intlMessages = require('./intlMessages');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_enzyme2.default.configure({ adapter: new _enzymeAdapterReact2.default() });

// Create the IntlProvider to retrieve context for wrapping around.
/**
 * Components using the react-intl module require access to the intl context.
 * This is not available when mounting single components in Enzyme.
 * These helper functions aim to address that and wrap a valid,
 * English-locale intl context around them.
 */

var intlProvider = new _reactIntl.IntlProvider({ locale: 'en', intlMessages: _intlMessages.intlMessages }, {});

var _intlProvider$getChil = intlProvider.getChildContext(),
    intl = _intlProvider$getChil.intl;

/**
 * When using React-Intl `injectIntl` on components, props.intl is required.
 */


var nodeWithIntlProp = function nodeWithIntlProp(node) {
  return _react2.default.cloneElement(node, { intl: intl });
};

var shallowWithIntl = exports.shallowWithIntl = function shallowWithIntl(node) {
  var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      context = _ref.context;

  return (0, _enzyme.shallow)(nodeWithIntlProp(node), { context: Object.assign({}, context, { intl: intl }) });
};

var mountWithIntl = exports.mountWithIntl = function mountWithIntl(node) {
  var _ref2 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      context = _ref2.context,
      childContextTypes = _ref2.childContextTypes;

  return (0, _enzyme.mount)(nodeWithIntlProp(node), {
    context: Object.assign({}, context, { intl: intl }),
    childContextTypes: Object.assign({}, { intl: _reactIntl.intlShape }, childContextTypes)
  });
};

var renderWithIntl = exports.renderWithIntl = function renderWithIntl(node) {
  var _ref3 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      context = _ref3.context,
      childContextTypes = _ref3.childContextTypes;

  return (0, _enzyme.render)(nodeWithIntlProp(node), {
    context: Object.assign({}, context, { intl: intl }),
    childContextTypes: Object.assign({}, { intl: _reactIntl.intlShape }, childContextTypes)
  });
};