'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.timeBomb = exports.createTestStore = exports.createMockApiMiddleware = exports.getRSAAResponse = exports.makeFakeError = exports.jsonParseError = exports.makeApiResponse = exports.fakePayload = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _reduxApiMiddleware = require('redux-api-middleware');

var _reduxMockStore = require('redux-mock-store');

var _reduxMockStore2 = _interopRequireDefault(_reduxMockStore);

var _reduxThunk = require('redux-thunk');

var _reduxThunk2 = _interopRequireDefault(_reduxThunk);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var fakePayload = exports.fakePayload = { foo: 'bar' };

// Create mock response for testing
var makeApiResponse = exports.makeApiResponse = function makeApiResponse(response) {
  var status = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 200;
  var statusText = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'OK';
  var headers = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : { 'Content-Type': 'application/json' };

  var init = {
    status: status,
    statusText: statusText,
    headers: headers
  };
  return new window.Response(JSON.stringify(response), init);
};

var jsonParseError = exports.jsonParseError = function jsonParseError() {
  try {
    JSON.parse('+data+');
  } catch (err) {
    return err;
  }
};

var makeFakeError = exports.makeFakeError = function makeFakeError() {
  var response = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  var status = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 400;
  var statusText = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'Bad Request';

  var error = new Error('Error');
  error.response = makeApiResponse(response, status, statusText);
  return error;
};

var getRSAAResponse = exports.getRSAAResponse = function getRSAAResponse(action, payload, state) {
  var response = {
    json: function json() {
      return new Promise(function (resolve) {
        resolve(payload);
      });
    }
  };
  return action[_reduxApiMiddleware.RSAA].types[1].payload(action, state, response);
};

var createMockApiMiddleware = exports.createMockApiMiddleware = function createMockApiMiddleware() {
  var dispatchedRSAAs = [];

  return {
    middleware: function middleware(store) {
      return function (next) {
        return function (action) {
          if (!action[_reduxApiMiddleware.RSAA]) {
            return next(action);
          }

          dispatchedRSAAs.push(action);

          // short circuit middleware chain by not calling next()
        };
      };
    },
    getDispatchedRSAAs: function getDispatchedRSAAs() {
      return dispatchedRSAAs;
    },
    clear: function clear() {
      dispatchedRSAAs.length = 0;
    },
    verifyRSAAs: function verifyRSAAs(expectedRSAAs) {
      return JSON.stringify(dispatchedRSAAs) === JSON.stringify(expectedRSAAs);
    }
  };
};

var createTestStore = exports.createTestStore = function createTestStore() {
  var defaultState = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  var apiMiddleware = createMockApiMiddleware();
  var middleware = [apiMiddleware.middleware, _reduxThunk2.default];
  var store = (0, _reduxMockStore2.default)(middleware)(defaultState);

  var verifyActions = function verifyActions() {
    var expectedActions = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];

    var dispatchedActions = store.getActions();
    expect(dispatchedActions).toHaveLength(expectedActions.length);
    expectedActions.forEach(function (action, i) {
      if (typeof action === 'string') {
        expect(dispatchedActions[i].type).toBe(action);
      } else {
        expect(dispatchedActions[i]).toEqual(action);
      }
    });
  };

  var clear = function clear() {
    store.clearActions();
    apiMiddleware.clear();
  };

  return _extends({
    store: store
  }, store, apiMiddleware, {
    verifyActions: verifyActions,
    clear: clear
  });
};

var timeBomb = exports.timeBomb = function timeBomb(expiryDate) {
  var today = new Date();
  var hasExpired = today > expiryDate;
  expect(hasExpired).toBeFalsy();
};